==> filter_tabs_moodle43_2026020903.zip: tabs/lang/en/filter_tabs.php <==
<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Language file
 *
 * @package    filter_tabs
 * @copyright  2013 Stefan Lehneis, University of Regensburg <stefan.lehneis@rz.uni-regensburg.de> /
 *             2014 Alexander Bias, Ulm University <alexander.bias@uni-ulm.de> /
 *             2017 José Puente <jpuentefs@gmail.com>
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

defined('MOODLE_INTERNAL') || die();

$string['filtername'] = 'Tabs';
$string['pluginname'] = 'Tabs';
$string['bootstrapheading'] = 'Bootstrap';
$string['selecttabs'] = 'Select tabs type';
$string['selecttabs_desc'] = 'Select Bootstrap 2 or Bootstrap 4 tabs for use with Bootstrap based themes, or legacy YUI tabs.';
$string['enableyui'] = 'Enable legacy YUI tabs';
$string['enablebootstrap2'] = 'Enable Bootstrap 2 tabs for use with Bootstrap 2 based themes';
$string['enablebootstrap4'] = 'Enable Bootstrap 4 tabs for use with Bootstrap 4 based themes';
$string['selecttabs_hint'] = 'Bootstrap version used by the current theme';
$string['suggestedoption'] = 'Suggested option';
$string['previewheading'] = 'Preview';
$string['privacy:metadata'] = 'The tabs filter does not store any personal data.';

==> filter_tabs_moodle51_2026020953.zip: tabs/lang/en/filter_tabs.php <==
<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Language file
 *
 * @package    filter_tabs
 * @copyright  2013 Stefan Lehneis, University of Regensburg <stefan.lehneis@rz.uni-regensburg.de> /
 *             2014 Alexander Bias, Ulm University <alexander.bias@uni-ulm.de> /
 *             2017 José Puente <jpuentefs@gmail.com>
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

defined('MOODLE_INTERNAL') || die();

$string['bootstrapheading'] = 'Bootstrap';
$string['enablebootstrap2'] = 'Enable Bootstrap 2 tabs for use with Bootstrap 2 based themes';
$string['enablebootstrap4'] = 'Enable Bootstrap 4 tabs for use with Bootstrap 4 based themes';
$string['enablebootstrap5'] = 'Enable Bootstrap 5 tabs for use with Bootstrap 5 based themes';
$string['enableyui'] = 'Enable legacy YUI tabs';
$string['filtername'] = 'Tabs';
$string['pluginname'] = 'Tabs';
$string['previewheading'] = 'Preview';
$string['privacy:metadata'] = 'The tabs filter does not store any personal data.';
$string['selecttabs'] = 'Select tabs type';
$string['selecttabs_desc'] = 'Select Bootstrap 2, 4 or 5 tabs for use with Bootstrap based themes, or legacy YUI tabs.';
$string['selecttabs_hint'] = 'Bootstrap version used by the current theme';
$string['suggestedoption'] = 'Suggested option';
